from async_image_save.tasks import async_save


def save_image(imagefield_data, instance):
    #deconstruct the file into something celery can pickle and send to the worker
    data = {}
    file = []
    file.append(imagefield_data.field_name)
    file.append(imagefield_data.name)
    file.append(imagefield_data.content_type)
    file.append(imagefield_data.size)           
    file.append(imagefield_data.charset)
    data['data'] = imagefield_data.read()
            
    #send the image to be saved by a worker
    async_save.delay(data, file, instance.__class__, instance.pk)



from distutils.core import setup
import async_image_save

long_description = open('README.rst').read()

setup(
    name='django-async-gt',
    version='0.1',
    packages=['async_image_save',],
    description='a simple app to asynchronously upload images with Django, using Celery',
    long_description=long_description,
    author='Gregory Terzian',
    author_email='gregory.terzian@gmail.com',
    license='BSD License',
    url='http://github.com/gterzian/django_async.git',
    platforms=["any"],
    requires=['django', 'celery', 'pil'],
    classifiers=[
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Environment :: Web Environment',
    ],
)